//
//  TSSetingVC.swift
//  AIEmoji
//
//  Created by 100Years on 2025/1/16.
//

import Combine
import SwiftUI


class ListEventPublisher {
    /// 设置
    let settingPublisher = PassthroughSubject<SettingType, Never>()
    /// 进入订阅详情页
    let enterPurchasePublisher = PassthroughSubject<Bool, Never>()
}

class TSSetingVC: TSBaseVC {
    
    var viewModel: TSSetingViewModel = TSSetingViewModel()
    var publisher: ListEventPublisher = .init()
    
    
    lazy var navBarView: TSBaseNavContentBarView = {
        let navBarView = TSBaseNavContentBarView()

        let titleImageView = UIImageView.createImageView(imageName: "nav_title_setting",contentMode: .scaleToFill)
        navBarView.barView.addSubview(titleImageView)
        titleImageView.snp.makeConstraints { make in
            make.center.equalToSuperview()
            make.width.equalTo(375)
            make.height.equalTo(48)
        }

        return navBarView
    }()
    
    
    lazy var hostVc: UIHostingController<TSSettingListView> = {
        let vc = UIHostingController(rootView: TSSettingListView(viewModel: viewModel, publisher: publisher))
        vc.view.backgroundColor = .clear
        return vc
    }()
    
    override func createView() {
        
        setViewBgImageNamed(named: kViewBJ)
        
        edgesForExtendedLayout = []
        navBarContentView.addSubview(navBarView)
        navBarView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
        contentView.addSubview(hostVc.view)
        hostVc.view.snp.makeConstraints { make in
            make.top.equalTo(0)
            make.leading.trailing.bottom.equalToSuperview()
        }
    }
    
    override func dealThings() {
        
        publisher.enterPurchasePublisher.receive(on: DispatchQueue.main).sink { [weak self] _ in
            guard let self = self else { return }
            viewModel.pushVipPurchase(parent: self)
        }.store(in: &cancellable)
        

        publisher.settingPublisher.receive(on: DispatchQueue.main).sink{ [weak self] type in
            guard let self = self else {
                return
            }
            
            switch type {
            case .tutorial:
                viewModel.pushTutorials(parent: self)
            case .shareus:
                viewModel.shareApp(parent: self)
            case .agreement:
                viewModel.showAgreement(parent: self)
            case .privacy:
                viewModel.showPrivacy(parent: self)
            case .about:
                break
            case .rateus:
                viewModel.rateAction()
            }
            
        }.store(in: &cancellable)
        
        NotificationCenter.default.addObserver(self, selector: #selector(vipInfoChanged), name: .kPurchaseDidChanged, object: nil)
    }
    
    @objc func vipInfoChanged() {
        kExecuteOnMainThread {
            self.viewModel.isViper = kPurchaseToolShared.isVip
        }
    }
}
